@@ -1,5 +1,5 @@
 '''
-Tenable.ad session
+Tenable Identity Exposure session
 '''
 import warnings
 import os
@@ -34,7 +34,7 @@ class TenableAD(APIPlatform):
     _conv_json = True
 
     def _session_auth(self, **kwargs):
-        msg = 'Session Auth isn\'t supported with the Tenable.ad APIs'
+        msg = 'Session Auth isn\'t supported with the Tenable Identity Exposure APIs'
         warnings.warn(msg)
         self._log.warning(msg)
 
@@ -56,7 +56,7 @@ class TenableAD(APIPlatform):
     def about(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad About APIs <about>`.
+        :doc:`Tenable Identity Exposure About APIs <about>`.
         '''
         return AboutAPI(self)
 
@@ -64,7 +64,7 @@ class TenableAD(APIPlatform):
     def api_keys(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad API-Keys APIs <api_keys>`.
+        :doc:`Tenable Identity Exposure API-Keys APIs <api_keys>`.
         '''
         return APIKeyAPI(self)
 
@@ -72,7 +72,7 @@ class TenableAD(APIPlatform):
     def attack_types(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Attack Types APIs <attack_types>`.
+        :doc:`Tenable Identity Exposure Attack Types APIs <attack_types>`.
         '''
         return AttackTypesAPI(self)
 
@@ -80,7 +80,7 @@ class TenableAD(APIPlatform):
     def category(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Category APIs <category>`.
+        :doc:`Tenable Identity Exposure Category APIs <category>`.
         '''
         return CategoryAPI(self)
 
@@ -88,7 +88,7 @@ class TenableAD(APIPlatform):
     def checker(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Checker APIs <checker>`.
+        :doc:`Tenable Identity Exposure Checker APIs <checker>`.
         '''
         return CheckerAPI(self)
 
@@ -96,7 +96,7 @@ class TenableAD(APIPlatform):
     def checker_option(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Checker option APIs <checker_option>`.
+        :doc:`Tenable Identity Exposure Checker option APIs <checker_option>`.
         '''
         return CheckerOptionAPI(self)
 
@@ -104,7 +104,7 @@ class TenableAD(APIPlatform):
     def dashboard(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Dashboard APIs <dashboard>`.
+        :doc:`Tenable Identity Exposure Dashboard APIs <dashboard>`.
         '''
         return DashboardAPI(self)
 
@@ -112,7 +112,7 @@ class TenableAD(APIPlatform):
     def directories(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Directories APIs <directories>`.
+        :doc:`Tenable Identity Exposure Directories APIs <directories>`.
         '''
         return DirectoriesAPI(self)
 
@@ -120,7 +120,7 @@ class TenableAD(APIPlatform):
     def infrastructure(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Infrastructure APIs <infrastructure>`.
+        :doc:`Tenable Identity Exposure Infrastructure APIs <infrastructure>`.
         '''
         return InfrastructureAPI(self)
 
@@ -128,7 +128,7 @@ class TenableAD(APIPlatform):
     def ldap_configuration(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad LDAP Configuration APIs <ldap_configuration>`.
+        :doc:`Tenable Identity Exposure LDAP Configuration APIs <ldap_configuration>`.
         '''
         return LDAPConfigurationAPI(self)
 
@@ -136,7 +136,7 @@ class TenableAD(APIPlatform):
     def lockout_policy(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Lockout Policy APIs <lockout_policy>`.
+        :doc:`Tenable Identity Exposure Lockout Policy APIs <lockout_policy>`.
         '''
         return LockoutPolicyAPI(self)
       
@@ -144,7 +144,7 @@ class TenableAD(APIPlatform):
     def preference(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Preference APIs <preference>`.
+        :doc:`Tenable Identity Exposure Preference APIs <preference>`.
         '''
         return PreferenceAPI(self)
 
@@ -152,7 +152,7 @@ class TenableAD(APIPlatform):
     def profiles(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Profiles APIs <profiles>`.
+        :doc:`Tenable Identity Exposure Profiles APIs <profiles>`.
         '''
         return ProfilesAPI(self)
 
@@ -160,7 +160,7 @@ class TenableAD(APIPlatform):
     def reason(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Reason APIs <reason>`.
+        :doc:`Tenable Identity Exposure Reason APIs <reason>`.
         '''
         return ReasonAPI(self)
 
@@ -168,7 +168,7 @@ class TenableAD(APIPlatform):
     def roles(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Roles APIs <roles>`.
+        :doc:`Tenable Identity Exposure Roles APIs <roles>`.
         '''
         return RolesAPI(self)
 
@@ -176,7 +176,7 @@ class TenableAD(APIPlatform):
     def saml_configuration(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad SAML configuration APIs <saml_configuration>`.
+        :doc:`Tenable Identity Exposure SAML configuration APIs <saml_configuration>`.
         '''
         return SAMLConfigurationAPI(self)
 
@@ -184,7 +184,7 @@ class TenableAD(APIPlatform):
     def score(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Score APIs <score>`.
+        :doc:`Tenable Identity Exposure Score APIs <score>`.
         '''
         return ScoreAPI(self)
 
@@ -192,7 +192,7 @@ class TenableAD(APIPlatform):
     def topology(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Topology APIs <topology>`.
+        :doc:`Tenable Identity Exposure Topology APIs <topology>`.
         '''
         return TopologyAPI(self)
 
@@ -200,7 +200,7 @@ class TenableAD(APIPlatform):
     def users(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Users APIs <users>`.
+        :doc:`Tenable Identity Exposure Users APIs <users>`.
         '''
         return UsersAPI(self)
 
@@ -208,6 +208,6 @@ class TenableAD(APIPlatform):
     def widgets(self):
         '''
         The interface object for the
-        :doc:`Tenable.ad Widget APIs <widget>`.
+        :doc:`Tenable Identity Exposure Widget APIs <widget>`.
         '''
         return WidgetsAPI(self)
