@@ -2,7 +2,7 @@
 Exports
 =======
 
-The following methods allow for interaction into the Tenable.io
+The following methods allow for interaction into the Tenable Vulnerability Management
 :devportal:`exports <exports>` API endpoints.
 
 Methods available on ``tio.exports``:
@@ -269,6 +269,8 @@ class ExportsAPI(APIEndpoint):
                 Should we return assets that have a ServiceNOW sysid?
                 if ``True`` only assets with an id will be returned.
                 if ``False`` only assets without an id will be returned.
+            include_open_ports (bool, optional):
+                Should we include open ports of assets in the exported chunks?
             chunk_size (int, optional):
                 How many asset objects should be returned per chunk of data?
                 The default is ``1000``.
@@ -379,7 +381,7 @@ class ExportsAPI(APIEndpoint):
                 Findings first discovered after this timestamp will be
                 returned.
             indexed_at (int, optional):
-                Findings indexed into Tenable.io after this timestamp will
+                Findings indexed into Tenable Vulnerability Management after this timestamp will
                 be returned.
             last_fixed (int, optional):
                 Findings fixed after this timestamp will be returned.  Note
@@ -399,6 +401,10 @@ class ExportsAPI(APIEndpoint):
                 Only return findings with the specified plugin type.
             scan_uuid (uuid, optional):
                 Only return findings with the specified scan UUID.
+            source (list[str], optional):
+                Only return vulnerabilities for assets that have the specified scan source.
+            severity_modification_type (list[str], optional):
+                Only return vulnerabilities with the specified severity modification type.
             severity (list[str], optional):
                 Only return findings with the specified severities.
             state (list[str], optional):
