@@ -2,7 +2,7 @@
 Version3 API
 ============
 
-The following sub-package allows for interaction with the Tenable.io - Version3API
+The following sub-package allows for interaction with the Tenable Vulnerability Management - Version3API
 
 Methods available on ``tio.v3``:
 
@@ -24,14 +24,14 @@ from tenable.io.v3.explore import Explore
 
 class Version3API(APIEndpoint):
     """
-    This will contain property for all resources/app under Tenable.io - V3.
+    This will contain property for all resources/app under Tenable Vulnerability Management - V3.
     """
 
     @property
     def explore(self):
         """
         The interface object for the
-         :doc:`Tenable.io v3 explore <explore/index>`
+         :doc:`Tenable Vulnerability Management v3 explore <explore/index>`
         """
         return Explore(self._api)
 
@@ -39,6 +39,6 @@ class Version3API(APIEndpoint):
     def access_control(self):
         """
         The interface object for the
-         :doc:`Tenable.io v3 access control <access_control>`
+         :doc:`Tenable Vulnerability Management v3 access control <access_control>`
         """
         return AccessControlAPI(self._api)
