@@ -2,9 +2,9 @@
 Users
 =====
 
-The following methods allow for interaction into the Tenable.sc
-:sc-api:`User <User.html>` API.  These items are typically seen under the
-**Users** section of Tenable.sc.
+The following methods allow for interaction into the Tenable Security Center
+:sc-api:`User <User.htm>` API.  These items are typically seen under the
+**Users** section of Tenable Security Center.
 
 Methods available on ``sc.users``:
 
@@ -139,7 +139,7 @@ class UserAPI(SCEndpoint):
         '''
         Creates a user.
 
-        :sc-api:`user: create <User.html#user_POST>`
+        :sc-api:`user: create <User.htm#user_POST>`
 
         Args:
             username (str):
@@ -195,7 +195,7 @@ class UserAPI(SCEndpoint):
             org (int, optional):
                 If logged in as an administrator, and creating a security
                 manager account, the organization id must be passed in order to
-                inform Tenable.sc which organization to create the security
+                inform Tenable Security Center which organization to create the security
                 manager within.
             phone (str, optional):
                 A phone number to associate to the user.
@@ -235,7 +235,7 @@ class UserAPI(SCEndpoint):
         '''
         Returns the details for a specific user.
 
-        :sc-api:`user: details <User.html#UserRESTReference-/user/{id}>`
+        :sc-api:`user: details <User.htm#UserRESTReference-/user/{id}>`
 
         Args:
             id (int): The identifier for the user.
@@ -260,7 +260,7 @@ class UserAPI(SCEndpoint):
         '''
         Edits a user.
 
-        :sc-api:`user: edit <User.html#user_id_PATCH>`
+        :sc-api:`user: edit <User.htm#user_uuid_PATCH>`
 
         Args:
             address (str, optional):
@@ -310,7 +310,7 @@ class UserAPI(SCEndpoint):
             org (int, optional):
                 If logged in as an administrator, and creating a security
                 manager account, the organization id must be passed in order to
-                inform Tenable.sc which organization to create the security
+                inform Tenable Security Center which organization to create the security
                 manager within.
             password (str, optional):
                 The user password
@@ -352,7 +352,7 @@ class UserAPI(SCEndpoint):
         '''
         Removes a user.
 
-        :sc-api:`user: delete <User.html#user_id_DELETE>`
+        :sc-api:`user: delete <User.htm#user_uuid_DELETE>`
 
         Args:
             id (int): The numeric identifier for the user to remove.
@@ -371,7 +371,7 @@ class UserAPI(SCEndpoint):
         '''
         Retrieves the list of user definitions.
 
-        :sc-api:`user: list <User.html#user_GET>`
+        :sc-api:`user: list <User.htm#user_GET>`
 
         Args:
             fields (list, optional):
